@@ -12,8 +12,8 @@ Credit means "right", gains/income/revenues/liabilities/equity increased with cr
 from datetime import datetime, timedelta
 from decimal import Decimal
 from typing import Optional, Type
-
 from math import floor
+from django.contrib.auth.models import User
 from django.core.exceptions import ValidationError
 from jacc.helpers import sum_queryset
 from django.conf import settings
@@ -103,6 +103,27 @@ class EntryType(models.Model):
         return "{} ({})".format(self.name, self.code)
 
 
+class AccountEntryNote(models.Model):
+    account_entry = models.ForeignKey(
+        "AccountEntry", verbose_name=_("account entry"), related_name="note_set", on_delete=models.CASCADE
+    )
+    created = models.DateTimeField(verbose_name=_("created"), default=now, db_index=True, editable=False, blank=True)
+    created_by = models.ForeignKey(
+        User,
+        verbose_name=_("created by"),
+        editable=False,
+        blank=True,
+        related_name="accountentrynote_set",
+        on_delete=models.CASCADE,
+    )
+    last_modified = models.DateTimeField(verbose_name=_("last modified"), auto_now=True, editable=False, blank=True)
+    note = models.TextField(_("note"))
+
+    class Meta:
+        verbose_name = _("account entry note")
+        verbose_name_plural = _("account entry notes")
+
+
 class AccountEntryManager(models.Manager):
     pass
 
@@ -145,7 +166,7 @@ class AccountEntry(models.Model):
         blank=True,
         on_delete=models.CASCADE,
         help_text=_("entry.source.file.help.text"),
-    )  # nopep8, pylint: disable=line-too-long
+    )
     source_invoice = models.ForeignKey(
         "Invoice",
         verbose_name=_("source invoice"),
@@ -155,7 +176,7 @@ class AccountEntry(models.Model):
         blank=True,
         on_delete=models.CASCADE,
         help_text=_("entry.source.invoice.help.text"),
-    )  # nopep8, pylint: disable=line-too-long
+    )
     settled_invoice = models.ForeignKey(
         "Invoice",
         verbose_name=_("settled invoice"),
@@ -165,7 +186,7 @@ class AccountEntry(models.Model):
         blank=True,
         on_delete=models.PROTECT,
         help_text=_("entry.settled.invoice.help.text"),
-    )  # nopep8, pylint: disable=line-too-long
+    )
     settled_item = models.ForeignKey(
         "AccountEntry",
         verbose_name=_("settled item"),
@@ -175,7 +196,7 @@ class AccountEntry(models.Model):
         blank=True,
         on_delete=models.PROTECT,
         help_text=_("entry.settled.item.help.text"),
-    )  # nopep8, pylint: disable=line-too-long
+    )
     parent = models.ForeignKey(
         "AccountEntry",
         verbose_name=_("account.entry.parent"),
@@ -185,7 +206,7 @@ class AccountEntry(models.Model):
         null=True,
         default=None,
         blank=True,
-    )  # nopep8, pylint: disable=line-too-long
+    )
     archived = models.BooleanField(_("archived"), default=False, blank=True)
 
     class Meta:
@@ -361,7 +382,7 @@ class Invoice(models.Model, CachedFieldsMixin):
         null=True,
         default=None,
         db_index=True,
-    )  # nopep8, pylint: disable=line-too-long
+    )
     unpaid_amount = models.DecimalField(
         verbose_name=_("unpaid amount"),
         max_digits=10,
@@ -371,7 +392,7 @@ class Invoice(models.Model, CachedFieldsMixin):
         null=True,
         default=None,
         db_index=True,
-    )  # nopep8, pylint: disable=line-too-long
+    )
     overpaid_amount = models.DecimalField(
         verbose_name=_("overpaid amount"),
         max_digits=10,
@@ -381,7 +402,7 @@ class Invoice(models.Model, CachedFieldsMixin):
         null=True,
         default=None,
         db_index=True,
-    )  # nopep8, pylint: disable=line-too-long
+    )
     close_date = models.DateTimeField(verbose_name=_("close date"), default=None, null=True, blank=True, db_index=True)
     late_days = models.SmallIntegerField(
         verbose_name=_("late days"), default=None, null=True, blank=True, db_index=True
